interface FindToolbarButtonByTextOptions {
    queryShadowButton?: boolean;
}
declare global {
    namespace Cypress {
        interface Chainable {
            /**
             * Returns the tab of the `ui5-tabcontainer` by its text.
             *
             * __Note:__ Has to be chained to a `ui5-tabcontainer`.
             *
             * __Note:__ This will not work for sub-tabs.
             *
             * @example cy.get('[ui5-tab-container]').findUi5TabByText('Tab 1');
             * @param {string} text The text of the tab that should be queried.
             */
            findUi5TabByText(text: string): Chainable<Element>;
            /**
             * Returns the open-popover button for sub-tabs by its text.
             *
             * __Note:__ Has to be chained to a `ui5-tabcontainer`.
             *
             * __Note:__ The tab only renders a button fur sub-tabs if the tab itself has content, otherwise the whole tab is responsible for opening the popover.
             *
             * @example cy.get('[ui5-tab-container]').findUi5TabOpenPopoverButtonByText('Tab 1.1');
             * @param {string} text The text of the sub-tab that should be queried.
             */
            findUi5TabOpenPopoverButtonByText(text: string): Chainable<Element>;
            /**
             * Returns the element that represents the `ui5-toolbar-button`.
             * When `options.queryShadowButton` is `true`, the internal `button` element is returned, otherwise the `ui5-button` element.
             *
             * __Note:__ This query can either be chained to a `ui5-toolbar` or not be chained at all.
             *
             * __Note:__ The `text` next needs to be unique in the respective scope.
             *
             * @example cy.findToolbarButtonByText("Button Text")
             * @example cy.get('[ui5-toolbar]').findToolbarButtonByText("Button Text")
             *
             * @param {string} text - The text of the button to search for. This text should be unique within the toolbar to ensure a single button is returned.
             * @param {FindToolbarButtonByTextOptions} [options] - An optional object containing configuration options for the query.
             * @param {boolean} [options.queryShadowButton=false] - If set to `true`, the internal `button` element will be returned instead of the `ui5-button` element.
             */
            findToolbarButtonByText(text: string, options?: FindToolbarButtonByTextOptions): Chainable<Element>;
            /**
             * Returns the internal input element inside the shadow-root.
             *
             * @private
             * @example cy.get('[ui5-checkbox]').findShadowInput();
             */
            findShadowInput(): Chainable<Element>;
        }
    }
}
export {};
